import React from "react";
import PropTypes from "prop-types";
import { makeStyles } from "@material-ui/core/styles";
import clsx from "clsx";
import {
  Card,
  CardHeader,
  CardContent,
  CardActions,
  Collapse,
  Avatar,
  IconButton,
  Typography,
  Grid,
  Tooltip
} from "@material-ui/core";
import ExpandMoreIcon from "@material-ui/icons/ExpandMore";
import MoreVertIcon from "@material-ui/icons/MoreVert";
import LibraryBooksIcon from "@material-ui/icons/LibraryBooks";
import styles from "../../../components/common/styles/expandableCardStyles";
import { useTranslation } from "react-i18next";

const useStyles = makeStyles(styles);

const AboutComponent = ({ onOpenDocumentation }) => {
  const classes = useStyles();
  const { t } = useTranslation();
  const [expanded, setExpanded] = React.useState(false);

  const handleExpandClick = () => {
    setExpanded(!expanded);
  };

  return (
    <Card>
      <CardHeader
        avatar={
          <Avatar aria-label="recipe" className={classes.avatar}>
            R
          </Avatar>
        }
        action={
          <IconButton aria-label="settings">
            <MoreVertIcon />
          </IconButton>
        }
        title={t("About.Title")}
        subheader={t("About.Subtitle")}
      />
      <CardContent>
        <Typography variant="h6" color="textSecondary">
          {t("About.WhatIs")}
        </Typography>
        <Typography variant="body2" color="textSecondary" component="p">
          {t("About.Content1")}
        </Typography>
        <br />
        <Typography variant="h6" color="textSecondary">
          {t("About.CurrentSystem")}
        </Typography>
        <Typography variant="body2" color="textSecondary" component="p">
          {t("About.Content4")}
        </Typography>
        <br />
        <Typography variant="h6" color="textSecondary">
          {t("System.Components.Server")}
        </Typography>
        <Typography variant="body2" color="textSecondary" component="p">
          {t("About.Description.Server")}
        </Typography>
        <br />
        <Typography variant="h6" color="textSecondary">
          {t("System.Components.Api")}
        </Typography>
        <Typography variant="body2" color="textSecondary" component="p">
          {t("About.Description.Api")}
        </Typography>
        <br />
        <Typography variant="h6" color="textSecondary">
          {t("System.Components.Frontend")}
        </Typography>
        <Typography variant="body2" color="textSecondary" component="p">
          {t("About.Description.Frontend")}
        </Typography>
      </CardContent>
      <CardActions disableSpacing>
        <Tooltip title={t("About.Actions.Documentation")}>
          <IconButton aria-label="documentation" onClick={onOpenDocumentation}>
            <LibraryBooksIcon />
          </IconButton>
        </Tooltip>
        <IconButton
          className={clsx(classes.expand, {
            [classes.expandOpen]: expanded
          })}
          onClick={handleExpandClick}
          aria-expanded={expanded}
          aria-label="show more"
        >
          <ExpandMoreIcon />
        </IconButton>
      </CardActions>
      <Collapse in={expanded} timeout="auto" unmountOnExit>
        <CardContent>
          <Typography variant="h6" color="textSecondary">
            {t("About.ContentTitle")}
          </Typography>
          <br />
          <Grid container spacing={1}>
            <Grid item xs={12}>
              <Typography paragraph>{t("About.Content2")}</Typography>
            </Grid>

            <Grid item xs={12}>
              <img
                className={classes.image}
                src="public/images/reverse-proxy2.jpg"
                alt="..."
              />
            </Grid>
            <Grid item xs={12}>
              <Typography paragraph>
                {t("About.Content1")} {t("About.Content3")}
              </Typography>
            </Grid>
          </Grid>
        </CardContent>
      </Collapse>
    </Card>
  );
};

AboutComponent.propTypes = {
  onOpenDocumentation: PropTypes.func.isRequired
};

export default AboutComponent;
