import React from "react";
import PropTypes from "prop-types";
import { makeStyles } from "@material-ui/core/styles";
import Chip from "@material-ui/core/Chip";
import Grid from "@material-ui/core/Grid";
import Divider from "@material-ui/core/Divider";
import Typography from "@material-ui/core/Typography";
import { useTranslation } from "react-i18next";

const useStyles = makeStyles((theme) => ({
  root: {
    width: "100%",
    maxWidth: 360,
    backgroundColor: theme.palette.background.paper,
    borderStyle: "solid",
    borderWidth: "1px",
    borderColor: theme.palette.primary.main
  },
  chip: {
    margin: theme.spacing(0.5)
  },
  section1: {
    margin: theme.spacing(0, 1)
  },
  section2: {
    margin: theme.spacing(1)
  }
}));

const SessionsRunningTimeChartTooltip = ({ payload }) => {
  const classes = useStyles();
  const { t } = useTranslation();

  return (
    <div className={classes.root}>
      <div className={classes.section1}>
        <Grid container alignItems="center">
          <Grid item xs>
            <Typography gutterBottom variant="h6">
              {`${t("Charts.Server.Sessions.RunningTime.Session")} ${
                payload.order
              }`}
            </Typography>
          </Grid>
        </Grid>
        <Typography color="textSecondary" variant="body2">
          {`id: ${payload.sessionId}`}
        </Typography>
      </div>
      <Divider variant="middle" />
      <div className={classes.section2}>
        <Typography gutterBottom variant="body2">
          {t("Charts.Server.Sessions.RunningTime.X")}
        </Typography>
        <div>
          {payload.label.split(" ").map((s) => {
            return (
              <Chip
                key={s}
                className={classes.chip}
                color="primary"
                label={s}
              />
            );
          })}
        </div>
      </div>
    </div>
  );
};

SessionsRunningTimeChartTooltip.propTypes = {
  payload: PropTypes.object.isRequired
};

export default SessionsRunningTimeChartTooltip;
