import * as types from "./actionTypes";
import initialState from "../../redux/reducers/initialState";
import { botType } from "./constants";

export default function chatbotReducer(state = initialState.bot, action) {
  switch (action.type) {
    case types.SUMMON_WIZARD:
      return { ...state, type: botType.wizard };

    case types.DISMISS_BOT:
      return { ...state, type: botType.none };

    case types.INITIALIZE_BOT_SESSION_STARTED:
      return {
        ...state,
        session: {
          ...state.session,
          [action.botType]: { loading: true, loaded: false }
        }
      };

    case types.INITIALIZE_BOT_SESSION_SUCCESS:
      return {
        ...state,
        session: {
          ...state.session,
          [action.botType]: {
            loading: false,
            loaded: true,
            ...action.payload
          }
        }
      };

    case types.INITIALIZE_BOT_CHAT_STARTED:
      return { ...state, chat: { loading: true, loaded: false } };

    case types.INITIALIZE_BOT_CHAT_SUCCESS:
      return {
        ...state,
        chat: { loading: false, loaded: true, ...action.payload }
      };

    case types.CLOSE_BOT_CHAT_SUCCESS:
      return { ...state, chat: initialState.bot.chat };

    case types.STORE_BOT_MESSAGE: {
      const storage = [...state.storage];
      storage.push(action.message);
      return { ...state, storage };
    }

    case types.CLEAR_BOT_STORAGE:
      return { ...state, storage: initialState.bot.storage };

    default:
      return state;
  }
}
