import React from "react";
import PropTypes from "prop-types";
import ForwardComponent from "./ForwardComponent";
import { useParams } from "react-router";
import { connect } from "react-redux";
import { bindActionCreators } from "redux";
import { loadServerData } from "../../../server/actionCreators";
import { loadSessionForwards } from "../../../session/actionCreators";
import Spinner from "../../../../components/common/Spinner";
import styles from "../../../../components/common/styles/divStyles";
import { useTranslation } from "react-i18next";
import { makeStyles } from "@material-ui/core/styles";

const useStyles = makeStyles(styles);

const ForwardContainer = ({ actions, forward, domain }) => {
  const params = useParams();
  const classes = useStyles();
  const { t } = useTranslation();

  const { sessionId } = params;

  if (!domain) {
    actions.loadServerData();
  }

  if (!forward) {
    actions.loadSessionForwards(sessionId);
  }

  const loading = !domain || !forward;
  if (loading) {
    return <Spinner />;
  }

  const handleForwardClick = forward => event => {
    const url = `${domain.scheme}://${domain.name}${
      forward.from
    }${forward.suffix || ""}`;
    window.open(url, "_blank");
    event.preventDefault();
  };

  return (
    <div className={classes.root}>
      <h3>{t("Forward.Title", forward)}</h3>
      <ForwardComponent
        forward={forward}
        handleForwardClick={handleForwardClick}
      />
    </div>
  );
};

ForwardContainer.propTypes = {
  actions: PropTypes.object.isRequired,
  forward: PropTypes.object,
  domain: PropTypes.object
};

function mapStateToProps(state, props) {
  const { sessionId, forwardId } = props.match.params;
  const session = state.forwards[sessionId];
  const forward = session?.find(z => z.forwardId === forwardId);

  return {
    forward,
    domain: state.server.data.domain
  };
}

function mapDispatchToProps(dispatch) {
  return {
    actions: bindActionCreators(
      { loadServerData, loadSessionForwards },
      dispatch
    )
  };
}

export default connect(mapStateToProps, mapDispatchToProps)(ForwardContainer);
