import React from "react";
import { connect } from "react-redux";
import { bindActionCreators } from "redux";
import PropTypes from "prop-types";
import { loadForwardOptions } from "../../actionCreators";
import ForwardOptionsAdvancedComponent from "./ForwardOptionsAdvancedComponent";
import Spinner from "../../../../../components/common/Spinner";
import { useTranslation } from "react-i18next";

const ForwardOptionsAdvancedContainer = ({ actions, optionsId, options }) => {
  const { t } = useTranslation();

  if (!options) {
    actions.loadForwardOptions(optionsId);
    return <Spinner />;
  }

  return (
    <>
      <h4>{t("Forward.Options.Title")}</h4>
      <ForwardOptionsAdvancedComponent options={options} />
    </>
  );
};

ForwardOptionsAdvancedContainer.propTypes = {
  actions: PropTypes.object.isRequired,
  optionsId: PropTypes.string.isRequired,
  options: PropTypes.object
};

function mapStateToProps(state, props) {
  const options = state.options[props.optionsId];

  return {
    options
  };
}

function mapDispatchToProps(dispatch) {
  return {
    actions: bindActionCreators({ loadForwardOptions }, dispatch)
  };
}

export default connect(
  mapStateToProps,
  mapDispatchToProps
)(ForwardOptionsAdvancedContainer);
