import React from "react";
import PropTypes from "prop-types";
import ExpandableCard from "../../../../../../components/common/ExpandableCard";
import { useTranslation } from "react-i18next";
import { CompareArrowsOutlined } from "@material-ui/icons";
import { makeStyles } from "@material-ui/core/styles";
import {
  Table,
  TableBody,
  TableContainer,
  TableHead,
  TableRow,
  Paper,
  Typography
} from "@material-ui/core";
import styles from "../../../../../../components/common/styles/tableStyles";
import {
  StyledTableCell,
  StyledTableRow
} from "../../../../../../components/common/MaterialTable";
const useStyles = makeStyles(styles);

const ChangePointsCard = ({ changePoints }) => {
  const classes = useStyles();
  const { t } = useTranslation();

  return (
    <ExpandableCard
      Icon={<CompareArrowsOutlined />}
      iconVariant="rounded"
      title={t("Forward.Options.ChangePoints.Label")}
      smallHeader
      Content={
        <>
          <Typography variant="caption" display="block" gutterBottom>
            {t("Forward.Options.ChangePoints.Definition")}
          </Typography>
          <TableContainer component={Paper}>
            <Table
              className={classes.narrowTable}
              size="small"
              aria-label="customized table"
            >
              <TableHead>
                <TableRow>
                  <StyledTableCell>
                    {t("Forward.Options.ChangePoints.HtmlTag")}
                  </StyledTableCell>
                  <StyledTableCell>
                    {t("Forward.Options.ChangePoints.Attribute")}
                  </StyledTableCell>
                </TableRow>
              </TableHead>
              <TableBody>
                <>
                  {changePoints.map(point => {
                    return (
                      <StyledTableRow key={changePoints.indexOf(point)}>
                        <StyledTableCell>{point.htmlTag}</StyledTableCell>
                        <StyledTableCell>{point.attribute}</StyledTableCell>
                      </StyledTableRow>
                    );
                  })}
                </>
              </TableBody>
            </Table>
          </TableContainer>
        </>
      }
    />
  );
};

ChangePointsCard.propTypes = {
  changePoints: PropTypes.array.isRequired
};

export default ChangePointsCard;
