import React from "react";
import PropTypes from "prop-types";
import ExpandableCard from "../../../../../../components/common/ExpandableCard";
import { useTranslation } from "react-i18next";
import { List } from "@material-ui/icons";
import { makeStyles } from "@material-ui/core/styles";
import {
  Table,
  TableBody,
  TableContainer,
  TableHead,
  TableRow,
  Paper
} from "@material-ui/core";
import styles from "../../../../../../components/common/styles/tableStyles";
import {
  StyledTableCell,
  StyledTableRow
} from "../../../../../../components/common/MaterialTable";

const useStyles = makeStyles(styles);

const KeyOverwriteDetailsComponent = ({ details }) => {
  const classes = useStyles();
  const { t } = useTranslation();

  return (
    <ExpandableCard
      Icon={<List />}
      iconVariant="rounded"
      title={t("Forward.Options.KeyOverwrite.Details")}
      smallHeader
      Content={
        <TableContainer component={Paper}>
          <Table
            className={classes.narrowTable}
            size="small"
            aria-label="customized table"
          >
            <TableHead>
              <TableRow>
                <StyledTableCell>
                  {t("Forward.Options.KeyOverwrite.Origin")}
                </StyledTableCell>
                <StyledTableCell>
                  {t("Forward.Options.KeyOverwrite.Substitute")}
                </StyledTableCell>
              </TableRow>
            </TableHead>
            <TableBody>
              <>
                {details.map(detail => {
                  return (
                    <StyledTableRow key={details.indexOf(detail)}>
                      <StyledTableCell>{detail.origin}</StyledTableCell>
                      <StyledTableCell>{detail.substitute}</StyledTableCell>
                    </StyledTableRow>
                  );
                })}
              </>
            </TableBody>
          </Table>
        </TableContainer>
      }
    />
  );
};

KeyOverwriteDetailsComponent.propTypes = {
  details: PropTypes.array.isRequired
};

export default KeyOverwriteDetailsComponent;
