import React from "react";
import PropTypes from "prop-types";
import { Grid } from "@material-ui/core";
import { makeStyles } from "@material-ui/core/styles";
import { useTranslation } from "react-i18next";
import styles from "../../../../../../components/common/styles/gridStyles";
import ActiveIcon from "../../../../../../components/common/ActiveIcon";
import KeyOverwriteDetailsComponent from "./KeyOverwriteDetailsComponent";

const useStyles = makeStyles(styles);

const KeyOverwriteSummary = ({ data }) => {
  const classes = useStyles();
  const { t } = useTranslation();
  const singleKey = data.details.length === 1;

  return (
    <>
      <Grid container>
        <Grid item xs={6} sm={3} md={3}>
          {`${t("General.Enabled")}: `}
          <ActiveIcon active={data.on} />
        </Grid>
        {singleKey && (
          <>
            <Grid item xs={6} sm={3} md={3}>
              {`${t("Forward.Options.KeyOverwrite.Origin")}: `}
              <span className={classes.value}>{data.details[0].origin}</span>
            </Grid>

            <Grid item xs={6} sm={3} md={3}>
              {`${t("Forward.Options.KeyOverwrite.Substitute")}: `}
              <span className={classes.value}>
                {data.details[0].substitute}
              </span>
            </Grid>
          </>
        )}
      </Grid>
      {!singleKey && (
        <>
          <br />
          <KeyOverwriteDetailsComponent details={data.details} />
        </>
      )}
    </>
  );
};

KeyOverwriteSummary.propTypes = {
  data: PropTypes.object.isRequired
};

export default KeyOverwriteSummary;
