import React, { useEffect } from "react";
import { connect } from "react-redux";
import { bindActionCreators } from "redux";
import PropTypes from "prop-types";
import { loadForwardOptions } from "../../actionCreators";
import ForwardOptionsComponent from "./ForwardOptionsComponent";

const ForwardOptionsContainer = ({ actions, forward, options }) => {
  useEffect(() => {
    actions.loadForwardOptions(forward.optionId);
  }, []);

  const forwardOptions = options[forward.optionId];

  return (
    <>
      {forwardOptions && (
        <ForwardOptionsComponent
          title={`${forward.from} >>> ${forward.to}`}
          options={forwardOptions}
        />
      )}
    </>
  );
};

ForwardOptionsContainer.propTypes = {
  actions: PropTypes.object.isRequired,
  forward: PropTypes.object.isRequired,
  options: PropTypes.object.isRequired
};

function mapStateToProps(state) {
  return {
    options: state.options
  };
}

function mapDispatchToProps(dispatch) {
  return {
    actions: bindActionCreators({ loadForwardOptions }, dispatch)
  };
}

export default connect(
  mapStateToProps,
  mapDispatchToProps
)(ForwardOptionsContainer);
