import React, { useCallback } from "react";
import PropTypes from "prop-types";
import {
  Button,
  Dialog,
  DialogActions,
  DialogContent,
  DialogTitle
} from "@material-ui/core";
import { useTranslation } from "react-i18next";
import ForwardOptionsContainer from "./ForwardOptionsContainer";
import { useHistory } from "react-router-dom";

const ForwardOptionsDialog = ({ open, forward, handleClose }) => {
  const { t } = useTranslation();
  const history = useHistory();

  const handleAdvancedClick = useCallback(
    () => history.push(`/forwards/${forward.sessionId}/${forward.forwardId}`),
    [forward]
  );

  return (
    <div>
      <Dialog
        open={open}
        onClose={handleClose}
        aria-labelledby="options-dialog-title"
        aria-describedby="optopns-dialog-content"
      >
        <DialogTitle id="options-dialog-title">
          {t("Forward.Options.Title")}
        </DialogTitle>
        <DialogContent id="optopns-dialog-content">
          {forward ? <ForwardOptionsContainer forward={forward} /> : "N/A"}
        </DialogContent>
        <DialogActions>
          <Button onClick={handleAdvancedClick} color="primary">
            {t("General.Advanced")}
          </Button>
          <Button onClick={handleClose} color="primary">
            {t("General.Close")}
          </Button>
        </DialogActions>
      </Dialog>
    </div>
  );
};

ForwardOptionsDialog.propTypes = {
  open: PropTypes.bool.isRequired,
  forward: PropTypes.object,
  handleClose: PropTypes.func.isRequired
};

export default ForwardOptionsDialog;
