import React, { useState } from "react";
import { connect } from "react-redux";
import { bindActionCreators } from "redux";
import PropTypes from "prop-types";
import MessageForAuthorDialog from "./MessageForAuthorDialog";
import { saveMessageForAuthor } from "../actionCreators";
import { showInfo, showError } from "../../snackbar/actionCreators";
import { useTranslation } from "react-i18next";

const MessageForAuthorContainer = ({ actions, open, handleClose }) => {
  const [messageForAuthor, setMessageForAuthor] = useState("");
  const { t } = useTranslation();

  const onMessageForAuthorChanged = (event) => {
    const value = event.target.value;
    setMessageForAuthor(value);
  };

  const saveMessage = () => {
    actions
      .saveMessageForAuthor(messageForAuthor)
      .then((event) => {
        if (event.success) actions.showInfo(t("Notifications.MessageSaved"));
        else actions.showError(event.message);
      })
      .catch((error) => {
        actions.showError(error);
      });
    setMessageForAuthor("");
    handleClose();
  };

  return (
    <MessageForAuthorDialog
      open={open}
      handleClose={handleClose}
      messageForAuthor={messageForAuthor}
      onMessageForAuthorChanged={onMessageForAuthorChanged}
      saveMessage={saveMessage}
    />
  );
};

MessageForAuthorContainer.propTypes = {
  actions: PropTypes.object.isRequired,
  open: PropTypes.bool.isRequired,
  handleClose: PropTypes.func.isRequired
};

function mapStateToProps() {
  return {};
}

function mapDispatchToProps(dispatch) {
  return {
    actions: bindActionCreators(
      { saveMessageForAuthor, showInfo, showError },
      dispatch
    )
  };
}

export default connect(
  mapStateToProps,
  mapDispatchToProps
)(MessageForAuthorContainer);
