import React from "react";
import PropTypes from "prop-types";
import TextField from "@material-ui/core/TextField";
import {
  Dialog,
  DialogContent,
  IconButton,
  Grid,
  Tooltip
} from "@material-ui/core";
import SendRoundedIcon from "@material-ui/icons/SendRounded";
import { useTranslation } from "react-i18next";

const MessageForAuthorDialog = ({
  open,
  handleClose,
  messageForAuthor,
  onMessageForAuthorChanged,
  saveMessage
}) => {
  const { t } = useTranslation();

  return (
    <div>
      <Dialog
        fullWidth
        open={open}
        onClose={handleClose}
        aria-labelledby="form-dialog-title"
      >
        <DialogContent>
          <Grid container>
            <Grid item xs={11} sm={11} md={11}>
              <TextField
                autoFocus
                id="message-for-author"
                label={t("Server.MessageForAuthor")}
                fullWidth
                value={messageForAuthor}
                onChange={onMessageForAuthorChanged}
              />
            </Grid>
            <Grid item xs={1} sm={1} md={1}>
              <Tooltip title={t("General.Send")}>
                <IconButton
                  aria-label="send message"
                  onClick={saveMessage}
                  color="primary"
                >
                  <SendRoundedIcon />
                </IconButton>
              </Tooltip>
            </Grid>
          </Grid>
        </DialogContent>
      </Dialog>
    </div>
  );
};

MessageForAuthorDialog.propTypes = {
  open: PropTypes.bool.isRequired,
  handleClose: PropTypes.func.isRequired,
  messageForAuthor: PropTypes.string.isRequired,
  onMessageForAuthorChanged: PropTypes.func.isRequired,
  saveMessage: PropTypes.func.isRequired
};

export default MessageForAuthorDialog;
