import React from "react";
import PropTypes from "prop-types";
import { makeStyles } from "@material-ui/core/styles";
import clsx from "clsx";
import {
  Card,
  CardHeader,
  CardContent,
  CardActions,
  Collapse,
  Avatar,
  IconButton
} from "@material-ui/core";
import ExpandMoreIcon from "@material-ui/icons/ExpandMore";
import SurroundSoundRoundedIcon from "@material-ui/icons/SurroundSoundRounded";
import ActiveSessionSummary from "./ActiveSessionSummary";
import styles from "../../../components/common/styles/expandableCardStyles";
import { useTranslation } from "react-i18next";
import SessionForwardsComponent from "../../session/components/SessionForwardsComponent";
import Spinner from "../../../components/common/Spinner";

const useStyles = makeStyles(styles);

const ActiveSessionComponent = ({
  session,
  expanded,
  handleExpandClick,
  forwards,
  openOptionsDialog,
  handleForwardClick
}) => {
  const classes = useStyles();
  const { t } = useTranslation();

  return (
    <Card>
      <CardHeader
        avatar={
          <Avatar aria-label="recipe" className={classes.avatar}>
            <SurroundSoundRoundedIcon />
          </Avatar>
        }
        action={
          <IconButton
            className={clsx(classes.expand, {
              [classes.expandOpen]: expanded
            })}
            onClick={handleExpandClick}
            aria-expanded={expanded}
            aria-label="show more"
          >
            <ExpandMoreIcon />
          </IconButton>
        }
        title={<strong>{t("Server.ActiveSession")}</strong>}
        subheader={t("Server.ActiveSessionSubtitle")}
      />
      <CardContent>
        <ActiveSessionSummary session={session} />
      </CardContent>
      <CardActions disableSpacing></CardActions>
      <Collapse in={expanded} timeout="auto" unmountOnExit>
        <CardContent>
          {!forwards || forwards.loading ? (
            <Spinner />
          ) : (
            forwards.loaded && (
              <SessionForwardsComponent
                session={session}
                forwards={forwards}
                openOptionsDialog={openOptionsDialog}
                showSessionInfo={false}
                handleForwardClick={handleForwardClick}
              />
            )
          )}
        </CardContent>
      </Collapse>
    </Card>
  );
};

ActiveSessionComponent.propTypes = {
  session: PropTypes.object.isRequired,
  expanded: PropTypes.bool.isRequired,
  handleExpandClick: PropTypes.func.isRequired,
  forwards: PropTypes.array,
  openOptionsDialog: PropTypes.func.isRequired,
  handleForwardClick: PropTypes.func.isRequired
};

export default ActiveSessionComponent;
