import React, { useEffect, useState } from "react";
import { connect } from "react-redux";
import { bindActionCreators } from "redux";
import PropTypes from "prop-types";
import { loadActiveSession } from "../actionCreators";
import { loadSessionForwards } from "../../session/actionCreators";
import { getActiveForwards } from "../selectors";
import ActiveSessionComponent from "./ActiveSessionComponent";
import ForwardOptionsDialog from "../../forwards/options/components/simple/ForwardOptionsDialog";

const ActiveSessionContainer = ({ actions, session, forwards, domain }) => {
  const [expanded, setExpanded] = useState(false);
  const [optionsDialogOpen, setOptionsDialogOpen] = useState(false);
  const [focusedForward, setFocusedForward] = useState(null);

  useEffect(() => {
    actions.loadActiveSession();
  }, []);

  const handleExpandClick = () => {
    const expand = !expanded;
    setExpanded(expand);
    if (expand) actions.loadSessionForwards(session.sessionId);
  };

  const handleOptionsDialogOpen = forward => () => {
    setFocusedForward(forward);
    setOptionsDialogOpen(true);
  };

  const handleOptionsDialogClose = () => {
    setOptionsDialogOpen(false);
    setFocusedForward(null);
  };

  const handleForwardClick = forward => event => {
    const url = `${domain.scheme}://${domain.name}${
      forward.from
    }${forward.suffix || ""}`;
    window.open(url, "_blank");
    event.preventDefault();
  };

  return (
    <>
      <ActiveSessionComponent
        session={session}
        expanded={expanded}
        handleExpandClick={handleExpandClick}
        forwards={forwards}
        openOptionsDialog={handleOptionsDialogOpen}
        handleForwardClick={handleForwardClick}
      />
      <ForwardOptionsDialog
        open={optionsDialogOpen}
        forward={focusedForward}
        handleClose={handleOptionsDialogClose}
      />
    </>
  );
};

ActiveSessionContainer.propTypes = {
  actions: PropTypes.object.isRequired,
  session: PropTypes.object.isRequired,
  forwards: PropTypes.array,
  domain: PropTypes.object
};

function mapStateToProps(state) {
  return {
    session: state.server.activeSession,
    forwards: getActiveForwards(state),
    domain: state.server.data.domain
  };
}

function mapDispatchToProps(dispatch) {
  return {
    actions: bindActionCreators(
      { loadActiveSession, loadSessionForwards },
      dispatch
    )
  };
}

export default connect(
  mapStateToProps,
  mapDispatchToProps
)(ActiveSessionContainer);
