import React, { useEffect, useState } from "react";
import { connect } from "react-redux";
import { bindActionCreators } from "redux";
import PropTypes from "prop-types";
import SessionListComponent from "./SessionListComponent";
import ForwardOptionsDialog from "../../forwards/options/components/simple/ForwardOptionsDialog";
import { loadServerSessions, loadSessionForwards } from "../actionCreators";

const SessionContainer = ({ actions, sessions, forwards }) => {
  const [optionsDialogOpen, setOptionsDialogOpen] = useState(false);
  const [focusedForward, setFocusedForward] = useState(null);

  useEffect(() => {
    actions.loadServerSessions();
  }, []);

  const handleToggle = sessionId => (_, expanded) => {
    if (expanded) actions.loadSessionForwards(sessionId);
  };

  const handleOptionsDialogOpen = forward => () => {
    setFocusedForward(forward);
    setOptionsDialogOpen(true);
  };

  const handleOptionsDialogClose = () => {
    setOptionsDialogOpen(false);
    setFocusedForward(null);
  };

  return (
    <>
      <SessionListComponent
        sessions={sessions}
        handleToggle={handleToggle}
        forwards={forwards}
        openOptionsDialog={handleOptionsDialogOpen}
      />
      <ForwardOptionsDialog
        open={optionsDialogOpen}
        forward={focusedForward}
        handleClose={handleOptionsDialogClose}
      />
    </>
  );
};

SessionContainer.propTypes = {
  actions: PropTypes.object.isRequired,
  sessions: PropTypes.array.isRequired,
  forwards: PropTypes.object.isRequired
};

function mapStateToProps(state) {
  return {
    sessions: state.sessions,
    forwards: state.forwards
  };
}

function mapDispatchToProps(dispatch) {
  return {
    actions: bindActionCreators(
      { loadServerSessions, loadSessionForwards },
      dispatch
    )
  };
}

export default connect(mapStateToProps, mapDispatchToProps)(SessionContainer);
