import React, { useEffect } from "react";
import PropTypes from "prop-types";
import Snackbar from "@material-ui/core/Snackbar";
import MuiAlert from "@material-ui/lab/Alert";
import { makeStyles } from "@material-ui/core/styles";
import { connect } from "react-redux";
import { snackbarType } from "../snackbarType";

function Alert(props) {
  return <MuiAlert elevation={6} variant="filled" {...props} />;
}

const useStyles = makeStyles((theme) => ({
  root: {
    width: "100%",
    "& > * + *": {
      marginTop: theme.spacing(2)
    }
  },
  info: {
    backgroundColor: theme.palette.primary.main
  }
}));

const ToastNotifier = ({ snackbar }) => {
  const classes = useStyles();
  const [open, setOpen] = React.useState(false);

  useEffect(() => {
    if (snackbar.type) setOpen(true);
  }, [snackbar]);

  const handleClose = (_, reason) => {
    if (reason === "clickaway") {
      return;
    }

    setOpen(false);
  };

  return (
    <div className={classes.root}>
      <Snackbar open={open} autoHideDuration={3000} onClose={handleClose}>
        <>
          {snackbar.type === snackbarType.info && (
            <Alert
              onClose={handleClose}
              severity="info"
              className={classes.info}
            >
              {snackbar.message}
            </Alert>
          )}

          {snackbar.type === snackbarType.success && (
            <Alert onClose={handleClose} severity="success">
              {snackbar.message}
            </Alert>
          )}

          {snackbar.type === snackbarType.error && (
            <Alert onClose={handleClose} severity="error">
              {snackbar.message}
            </Alert>
          )}

          {snackbar.type === snackbarType.warning && (
            <Alert onClose={handleClose} severity="warning">
              {snackbar.message}
            </Alert>
          )}
        </>
      </Snackbar>
    </div>
  );
};
ToastNotifier.propTypes = {
  snackbar: PropTypes.object
};

function mapStateToProps(state) {
  return {
    snackbar: state.snackbar
  };
}

function mapDispatchToProps() {
  return {};
}

export default connect(mapStateToProps, mapDispatchToProps)(ToastNotifier);
